@@ -190,8 +190,7 @@ class TestTimestreamLoader_UnitTests:
         result = loader._TimestreamLoader__load(
             data=[{
                 'valid': 1.0,
-                'time': int(expected_capture_time),
-                'version': 2
+                'time': int(expected_capture_time)
             }],
             capture_time=datetime(2021, 1, 1, 0, 0, 0, 0, pytz.UTC),
             upsert=True
@@ -443,7 +442,7 @@ class TestTimestreamLoader_UnitTests:
 
         # Test parse upsert item
         records = loader._TimestreamLoader__parse_item({
-            'time': 1609459200000,
+            'Time': 1609459200000,
             'integer': 10
         }, True, False)
         assert len(records) == 1
